km3pipe.dataclasses.Table
=========================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: Table

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Table.all
      ~Table.any
      ~Table.append_columns
      ~Table.argmax
      ~Table.argmin
      ~Table.argpartition
      ~Table.argsort
      ~Table.astype
      ~Table.byteswap
      ~Table.choose
      ~Table.clip
      ~Table.compress
      ~Table.conj
      ~Table.conjugate
      ~Table.copy
      ~Table.cumprod
      ~Table.cumsum
      ~Table.diagonal
      ~Table.dot
      ~Table.drop_columns
      ~Table.dump
      ~Table.dumps
      ~Table.field
      ~Table.fill
      ~Table.flatten
      ~Table.from_columns
      ~Table.from_dataframe
      ~Table.from_dict
      ~Table.from_rows
      ~Table.from_template
      ~Table.getfield
      ~Table.item
      ~Table.itemset
      ~Table.max
      ~Table.mean
      ~Table.min
      ~Table.newbyteorder
      ~Table.nonzero
      ~Table.partition
      ~Table.prod
      ~Table.ptp
      ~Table.put
      ~Table.ravel
      ~Table.repeat
      ~Table.reshape
      ~Table.resize
      ~Table.round
      ~Table.searchsorted
      ~Table.setfield
      ~Table.setflags
      ~Table.sort
      ~Table.sorted
      ~Table.squeeze
      ~Table.std
      ~Table.sum
      ~Table.swapaxes
      ~Table.take
      ~Table.to_dataframe
      ~Table.tobytes
      ~Table.tofile
      ~Table.tolist
      ~Table.tostring
      ~Table.trace
      ~Table.transpose
      ~Table.var
      ~Table.view
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Table.T
      ~Table.azimuth
      ~Table.base
      ~Table.ctypes
      ~Table.data
      ~Table.dir
      ~Table.dtype
      ~Table.flags
      ~Table.flat
      ~Table.imag
      ~Table.itemsize
      ~Table.nbytes
      ~Table.ndim
      ~Table.phi
      ~Table.pos
      ~Table.real
      ~Table.shape
      ~Table.size
      ~Table.strides
      ~Table.templates_avail
      ~Table.theta
      ~Table.triggered_rows
      ~Table.zenith
   
   